pylinc
======

A general-purposed utility kit for personal usage.

Installation
------------

```python
$ pip install pylinc[healpy]
```

`pylinc` is using a third-party package `healpy` for its `healpix` module.
If installation of `healpy` fails (this has been reported on Windows),
users can install `pylinc` without the `healpix` module:
```python
$ pip install pylinc
```
